-----------------------------------------------------------
--|> Core UI: Utils
-----------------------------------------------------------
local _, NS = ...

local gsub = gsub
local string_find = string.find
local WrapTextInColorCode = WrapTextInColorCode
local GetClassColor = GetClassColor
local select = select

--> SCALE COORDS
--: IN: X,Y coords of where to place something
--: OUT: X, Y coords based effective scale of the game window.fi
function NS.ScaleCoords(xPixel, yPixel)
    local xFactor = NS.Display.xFactor
    local yFactor = NS.Display.yFactor
    local x, y = xPixel / xFactor, yPixel / yFactor
    x, y = x - x % 1, y - y % 1
    return x * xFactor, y * yFactor
end

--> GET FRAME POSITION
function NS.GetFramePosition(frame)
    if not frame then
        return
    elseif frame:IsProtected() then
        return
    elseif not frame:GetLeft() then
        return
    end
    if frame then
        local s = frame:GetScale()
        local left, top = frame:GetLeft() * s, frame:GetTop() * s
        local w, h = frame:GetWidth() * s, frame:GetHeight() * s
        frame:ClearAllPoints()
        frame:SetPoint("TOPLEFT", UIParent, "BOTTOMLEFT", left / s, top / s)
        frame:SetWidth(w / s)
        frame:SetHeight(h / s)
        return left, top, w, h, s, "TOPLEFT"
    end
    return nil
end

--> Save Core Position
function NS.SaveCoreFramePosition()
    local x, y, w, h, s, point = NS.GetFramePosition(weizPVP_CoreFrame)
    NS.Options.Frames.X = x
    NS.Options.Frames.Y = y
    NS.Options.Frames.Width = w
    NS.Options.Frames.Height = h
    NS.Options.Frames.Point = point
    NS.Options.Frames.Scale = s
end

--> Set Core Position
function NS.SetCoreFramePosition()
    local settings = {}
    settings.xC = NS.Options.Frames.X
    settings.yC = NS.Options.Frames.Y
    settings.wC = NS.Options.Frames.Width
    settings.hC = NS.Options.Frames.Height
    settings.pointC = NS.Options.Frames.Point or "TOPLEFT"
    settings.sC = NS.Options.Frames.Scale
    settings.As = NS.Options.Frames.AutoScaleEnabled
    weizPVP_CoreFrame:ClearAllPoints()
    weizPVP_CoreFrame:SetHeight(settings.hC / settings.sC)
    weizPVP_CoreFrame:SetWidth(settings.wC / settings.sC)
    --> Check for autoscaling
    if not settings.As then
        weizPVP_CoreFrame:SetScale(settings.sC)
    else
        NS.Options.Frames.Scale = ConvertPixelsToUI(1, UIParent:GetEffectiveScale())
        weizPVP_CoreFrame:SetScale(NS.Options.Frames.Scale * NS.Options.Frames.AutoScaleMultiplier)
    end
    weizPVP_CoreFrame:SetPoint("TOPLEFT", UIParent, "BOTTOMLEFT", settings.xC / settings.sC, settings.yC / settings.sC)
end

--> Format Player Name for Display
function NS.FormatPlayerNameForDisplay(playerName)
    local charName = WrapTextInColorCode(gsub(playerName, "-(.*)", ""), select(4, GetClassColor(NS.PlayerDB[playerName].Class)))
    if not string_find(playerName, NS.PlayerRealm) then
        charName = charName .. "|cFFFF00CC*|r"
    end
    return charName
end

--> Format Relative Level for Display
-- @tparam number level Incoming level to format and color based on difference in levels vs the current player
function NS.FormatRelativeLevelForDisplay(level)
    if level then
        local playerLevel = NS.Player.Level
        if level == 0 then --> 0
            return "|cFFFF00CC??|r"
        elseif level < playerLevel - 20 then --> 20+ below
            return "|cFF7cffd1" .. level .. "|r"
        elseif level < playerLevel - 10 then --> 10-20 below
            return "|cFF7cd1ff" .. level .. "|r"
        elseif level < playerLevel then --> 1-9 below
            return "|cFF7cff7f" .. level .. "|r"
        elseif level > playerLevel then --> Higher level
            return "|cFFf7694a" .. level .. "|r"
        else
            return "|cFFffc863" .. level .. "|r"
        end
    end
end

--> Scale Main Window
-- local scaleX =  0
-- local scaleY = 0
-- local scale = 0
function NS.ScaleMainWindow()
  --> pre-update

  -- weizPVP_CoreFrame:ClearAllPoints()
  -- scaleX, scaleY = weizPVP_CoreFrame:GetCenter()
  -- scale = weizPVP_CoreFrame:GetScale()
  -- weizPVP_CoreFrame:SetPoint("CENTER", UIParent, "CENTER", scaleX* scale, scaleY* scale)

  --> update
    if NS.Options.Frames.AutoScaleEnabled == true then
        NS.Options.Frames.AutoScale = ConvertPixelsToUI(1, UIParent:GetEffectiveScale())
        weizPVP_CoreFrame:SetScale(NS.Options.Frames.AutoScaleMultiplier * NS.Options.Frames.AutoScale)
        NS.Options.Frames.Scale = NS.Options.Frames.AutoScaleMultiplier * NS.Options.Frames.AutoScale
    else
        weizPVP_CoreFrame:SetScale(NS.Options.Frames.Scale)
    end
    --> post-update
    -- weizPVP_CoreFrame:ClearAllPoints()
    NS.SaveCoreFramePosition()
    NS.SetCoreFramePosition()
end
